#! /bin/bash
# phase_by_transmission_clean_CF@2020
# last edit: 2021-06
# authors: Christelle Fraïsse

#-# usage: qsub phase_by_transmission_clean_CF@2020.sh
#-# prog required: beagle v4.0 ; GATK v3.4-0-g7e26428 ; vcftools v0.1.13 ; htslib v1.9 ; bcftools v1.9
#-# files required: NamesTrio1_Oad18ad31ad2.ped and NamesTrio2_Oad18ad31ad2.ped because redundant individuals for GATK; NamesTrio_Oad18ad31ad2.ped for BEAGLE
# 		    [a pedigree file produced with generate_PED.sh]
#-# description: Phase by transmission - clean.


## define global variables
toGATK=/share/nas-isem_e/genomique_integrative/Cione_WGS
toBEAGLE=/home/fchristelle/bin/beagle_4.0
toVCFTOOLS=/home/fchristelle/bin/vcftools_0.1.13/bin
toHTSLIB=/home/fchristelle/bin/htslib-1.9
toBCFTOOLS=/home/fchristelle/bin/bcftools-1.9
PROOT="/share/nas-isem_e/genomique_integrative/Cione_WGS"
refgen=/share/nas-isem_e/genomique_integrative/Cione_WGS/RefCiona/GCA_009617815.1_Ciona_intestinalis_HT_Hoya_T-line_assembly_2019_genomic.fna

## your joint sample
infolder=/share/nas-isem_e/genomique_integrative/Cione_WGS/assembly_2019/ciona_bwa-mapping_jointsamples_raw

## number of threads to use
nthr=30


##-EXTRA-## Correct contig order in the VCF file as it does not match anymore with the reference
${toBCFTOOLS}/bcftools sort ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2.clean.biallelic.noindels.vcf > ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2.clean.biallelic.noindels_ORDER.vcf


##-2-## SelectVariants
#  -V						VCF files (ROD Tracks)
#  -select 			NA		One or more criteria to use when selecting the data
#						'AF > 0.01'
#						'DP > 10.0'
#						set == "Intersection": occurred in both call sets, not filtered out
#						set == "NAME": occurred in the call set NAME only
#						set=NAME1-filteredInNAME: occurred in both call sets, but was not filtered in NAME1 but was filtered in NAME2
#						set=filteredInAll: occurred in both call sets, but was filtered out of both
#						set=NAME1-NAME2: a variant occurred in both NAME1 and NAME2 but not all sets
#  --sample_file 		NA		File containing a list of samples (one per line) to include. Can be specified multiple times
#  --concordance		NA		Output variants that were also called in this comparison track
#  --discordance 		NA		Output variants that were not called in this comparison track
#  --maxIndelSize 2147483647			indel size select
#  --mendelianViolationQualThreshold 0.0	Minimum genotype QUAL score for each trio member required to accept a site as a violation
#  --restrictAllelesTo 		ALL		Select only variants of a particular allelicity (ALL, MULTIALLELIC or BIALLELIC)
#  --selectTypeToInclude 	NA		Select only a certain type of variants from the input file (INDEL, SNP, MIXED, MNP, SYMBOLIC, NO_VARIATION)
#  --excludeFiltered 		NA		Don't include filtered loci in the analysis
#  --excludeNonVariants		NA		Exclude sites monomorphic after sample subsetting
#  --mendelianViolation 	NA		output mendelian violation sites only

java -Xmx4g -jar ${toGATK}/GenomeAnalysisTK.jar \
	-nt ${nthr} \
	-R ${refgen} \
	-T SelectVariants \
	--variant ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2.clean.biallelic.noindels_ORDER.vcf \
	-o ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2.clean.biallelic.noindels_filter.vcf \
	--excludeFiltered \

echo "# Filtered vcf with GATK"


##-3-## PhaseByTransmission
## Computes the most likely genotype combination and phases trios and parent/child pairs given their genotype likelihoods and a mutation prior.
## Phases all sites were parent/child transmission can be inferred unambiguously (i.e. exclude sites in which all individuals are heterozygous, Mendelian violations).
## Physical phasing across sites is automatically performed by Haplotype Caller (add PIG and PGT tags to the FORMAT field).
## Linkage information is stored differently to avoid collisions.
#  --DeNovoPrior 			1e-8	Prior for de novo mutations.
#  --MendelianViolationsFile			File to output the mendelian violation details.
## Missing genotypes are handled as follows:
#  --in parent/child pairs: 			If an individual genotype is missing at one site, the other one is phased if it is homozygous. 
#						No phasing probability is emitted.
#  --in trios: 					If the child is missing, parents are treated as separate individuals and phased if homozygous.
#						No phasing probability is emitted.
#  --in trios:					If one of the parents is missing, it is handled like a parent/child pair.
#						Phasing is done unless both the parent & child are heterozygous. Phasing probability is emitted.
#  --in trios:					If two individuals are missing, the remaining individual is phased if it is homozygous.
#						No phasing probability is emitted.

#FORMAT
# .|.

java -Xmx30g -jar ${toGATK}/GenomeAnalysisTK.jar \
	-T PhaseByTransmission \
	-R ${refgen} \
	-V ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2.clean.biallelic.noindels_filter.vcf \
	-o ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2.clean.biallelic.noindels_filter_phased_tmp.vcf \
	-ped ${PROOT}/NamesTrio1_Oad18ad31ad2.ped \
	--MendelianViolationsFile ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2.clean.biallelic.noindels_filter_phased.mendel_1 \

java -Xmx30g -jar ${toGATK}/GenomeAnalysisTK.jar \
        -T PhaseByTransmission \
        -R ${refgen} \
        -V ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2.clean.biallelic.noindels_filter_phased_tmp.vcf \
        -o ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2.clean.biallelic.noindels_filter_phasedWrong.vcf \
        -ped ${PROOT}/NamesTrio2_Oad18ad31ad2.ped \
        --MendelianViolationsFile ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2.clean.biallelic.noindels_filter_phased.mendel_2 \

echo "# finished Phase By Transmission with GATK"


##-3bis-## Re-correct the homozygous genotypes (REF and ALT) that have been changed by the PhaseByTransmission tool (which re-calculates genotype likelihoods)
list=(ad10_GATCAG_L004 ad11_ACTTGA_L003 ad12_CGATGT_L001 ad13_TTAGGC_L001 ad15_TGACCA_L001 ad16_ATCACG_L001 ad19_TGACCA_L003 ad22_CGATGT_L003 ad23_ATCACG_L003 ad24_TTAGGC_L004 ad25_CGATGT_L004 ad26_CAGATC_L002 ad27_ACTTGA_L002 ad29_TAGCTT_L001 ad30_TGACCA_L002 ad32_ACTTGA_L001 ad33_GATCAG_L001 ad34_GGCTAC_L003 ad35_CTTGTA_L003 ad3_CGATGT_L002 ad4_ATCACG_L002 ad6_GCCAAT_L004 ad7_ACTTGA_L004 ad9_GATCAG_L003 cr4_TAGCTT_L002 cr5_GGCTAC_L002 cr6_CTTGTA_L002 cr7_GGCTAC_L004 cr8_CTTGTA_L004 f1312_GCCAAT_L001 f1513_CAGATC_L001 f1612_ACAGTG_L001 f1819_CAGATC_L003 f1822_GCCAAT_L003 f2322_ACAGTG_L003 f2524_TGACCA_L004 f2627_GATCAG_L002 f26_CAGATC_L004 f2933_CTTGTA_L001 f3031_GCCAAT_L002 f3332_GGCTAC_L001 f3435_ATCACG_L004 f43_TTAGGC_L002 f710_TAGCTT_L004 f911_TAGCTT_L003)

for i in "${list[@]}"; do
echo ${i}
${toVCFTOOLS}/vcftools --vcf ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2.clean.biallelic.noindels_filter_phasedWrong.vcf --indv ${i} --recode --recode-INFO-all --out ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2.clean.biallelic.noindels_filter_phased_${i}
done

#homoRef genotypes
for i in "${list[@]}"; do
echo ${i}
${toVCFTOOLS}/vcftools --vcf ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2.clean.biallelic.noindels_filter_phased_${i}.recode.vcf --exclude-positions ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2_${i}_het2homoRef.pos --recode --recode-INFO-all --out ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2.clean.biallelic.noindels_filter_phased_${i}.nohomoRef
${toVCFTOOLS}/vcftools --vcf ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2.clean.biallelic.noindels_filter_phased_${i}.recode.vcf --positions ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2_${i}_het2homoRef.pos --recode --recode-INFO-all --out ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2.clean.biallelic.noindels_filter_phased_${i}.tmp
${toBCFTOOLS}/bcftools +setGT ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2.clean.biallelic.noindels_filter_phased_${i}.tmp.recode.vcf -- -t 'a' -n '0/0' > ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2.clean.biallelic.noindels_filter_phased_${i}.homoRef.recode.vcf
sed -i 's/0\/0:/0|0:/g' ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2.clean.biallelic.noindels_filter_phased_${i}.homoRef.recode.vcf
rm ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2.clean.biallelic.noindels_filter_phased_${i}.tmp.recode.vcf
done

#homoAlt genotypes
for i in "${list[@]}"; do
echo ${i}
${toVCFTOOLS}/vcftools --vcf ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2.clean.biallelic.noindels_filter_phased_${i}.nohomoRef.recode.vcf --exclude-positions ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2_${i}_het2homoAlt.pos --recode --recode-INFO-all --out ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2.clean.biallelic.noindels_filter_phased_${i}.nohomoRef-nohomoAlt
${toVCFTOOLS}/vcftools --vcf ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2.clean.biallelic.noindels_filter_phased_${i}.recode.vcf --positions ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2_${i}_het2homoAlt.pos --recode --recode-INFO-all --out ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2.clean.biallelic.noindels_filter_phased_${i}.tmp
${toBCFTOOLS}/bcftools +setGT ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2.clean.biallelic.noindels_filter_phased_${i}.tmp.recode.vcf -- -t 'a' -n '0/0' > ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2.clean.biallelic.noindels_filter_phased_${i}.homoAlt.recode.vcf
sed -i 's/0\/0:/1|1:/g' ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2.clean.biallelic.noindels_filter_phased_${i}.homoAlt.recode.vcf
rm ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2.clean.biallelic.noindels_filter_phased_${i}.tmp.recode.vcf
rm ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2.clean.biallelic.noindels_filter_phased_${i}.nohomoRef.recode.vcf             
done


#concatenating all VCFs for each individual
for i in "${list[@]}"; do
echo ${i}

${toHTSLIB}/bgzip ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2.clean.biallelic.noindels_filter_phased_${i}.nohomoRef-nohomoAlt.recode.vcf
${toHTSLIB}/tabix -p vcf ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2.clean.biallelic.noindels_filter_phased_${i}.nohomoRef-nohomoAlt.recode.vcf.gz

${toHTSLIB}/bgzip ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2.clean.biallelic.noindels_filter_phased_${i}.homoRef.recode.vcf
${toHTSLIB}/tabix -p vcf ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2.clean.biallelic.noindels_filter_phased_${i}.homoRef.recode.vcf.gz

${toHTSLIB}/bgzip ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2.clean.biallelic.noindels_filter_phased_${i}.homoAlt.recode.vcf
${toHTSLIB}/tabix -p vcf ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2.clean.biallelic.noindels_filter_phased_${i}.homoAlt.recode.vcf.gz

${toBCFTOOLS}/bcftools concat -a ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2.clean.biallelic.noindels_filter_phased_${i}.nohomoRef-nohomoAlt.recode.vcf.gz ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2.clean.biallelic.noindels_filter_phased_${i}.homoRef.recode.vcf.gz ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2.clean.biallelic.noindels_filter_phased_${i}.homoAlt.recode.vcf.gz > ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2_${i}.clean.recode.vcf

${toHTSLIB}/bgzip ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2_${i}.clean.recode.vcf
${toHTSLIB}/tabix -p vcf ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2_${i}.clean.recode.vcf.gz

done

#merge VCFs across individuals
${toBCFTOOLS}/bcftools merge --threads ${nthr} ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2_ad10_GATCAG_L004.clean.recode.vcf.gz ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2_ad11_ACTTGA_L003.clean.recode.vcf.gz ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2_ad12_CGATGT_L001.clean.recode.vcf.gz ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2_ad13_TTAGGC_L001.clean.recode.vcf.gz ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2_ad15_TGACCA_L001.clean.recode.vcf.gz ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2_ad16_ATCACG_L001.clean.recode.vcf.gz ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2_ad19_TGACCA_L003.clean.recode.vcf.gz ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2_ad22_CGATGT_L003.clean.recode.vcf.gz ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2_ad23_ATCACG_L003.clean.recode.vcf.gz ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2_ad24_TTAGGC_L004.clean.recode.vcf.gz ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2_ad25_CGATGT_L004.clean.recode.vcf.gz ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2_ad26_CAGATC_L002.clean.recode.vcf.gz ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2_ad27_ACTTGA_L002.clean.recode.vcf.gz ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2_ad29_TAGCTT_L001.clean.recode.vcf.gz ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2_ad30_TGACCA_L002.clean.recode.vcf.gz ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2_ad32_ACTTGA_L001.clean.recode.vcf.gz ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2_ad33_GATCAG_L001.clean.recode.vcf.gz ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2_ad34_GGCTAC_L003.clean.recode.vcf.gz ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2_ad35_CTTGTA_L003.clean.recode.vcf.gz ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2_ad3_CGATGT_L002.clean.recode.vcf.gz ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2_ad4_ATCACG_L002.clean.recode.vcf.gz ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2_ad6_GCCAAT_L004.clean.recode.vcf.gz ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2_ad7_ACTTGA_L004.clean.recode.vcf.gz ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2_ad9_GATCAG_L003.clean.recode.vcf.gz ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2_cr4_TAGCTT_L002.clean.recode.vcf.gz ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2_cr5_GGCTAC_L002.clean.recode.vcf.gz ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2_cr6_CTTGTA_L002.clean.recode.vcf.gz ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2_cr7_GGCTAC_L004.clean.recode.vcf.gz ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2_cr8_CTTGTA_L004.clean.recode.vcf.gz ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2_f1312_GCCAAT_L001.clean.recode.vcf.gz ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2_f1513_CAGATC_L001.clean.recode.vcf.gz ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2_f1612_ACAGTG_L001.clean.recode.vcf.gz ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2_f1819_CAGATC_L003.clean.recode.vcf.gz ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2_f1822_GCCAAT_L003.clean.recode.vcf.gz ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2_f2322_ACAGTG_L003.clean.recode.vcf.gz ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2_f2524_TGACCA_L004.clean.recode.vcf.gz ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2_f2627_GATCAG_L002.clean.recode.vcf.gz ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2_f26_CAGATC_L004.clean.recode.vcf.gz ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2_f2933_CTTGTA_L001.clean.recode.vcf.gz ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2_f3031_GCCAAT_L002.clean.recode.vcf.gz ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2_f3332_GGCTAC_L001.clean.recode.vcf.gz ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2_f3435_ATCACG_L004.clean.recode.vcf.gz ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2_f43_TTAGGC_L002.clean.recode.vcf.gz ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2_f710_TAGCTT_L004.clean.recode.vcf.gz ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2_f911_TAGCTT_L003.clean.recode.vcf.gz > ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2.clean.biallelic.noindels_filter_phased.vcf

#arrange files
list=(ad10_GATCAG_L004 ad11_ACTTGA_L003 ad12_CGATGT_L001 ad13_TTAGGC_L001 ad15_TGACCA_L001 ad16_ATCACG_L001 ad19_TGACCA_L003 ad22_CGATGT_L003 ad23_ATCACG_L003 ad24_TTAGGC_L004 ad25_CGATGT_L004 ad26_CAGATC_L002 ad27_ACTTGA_L002 ad29_TAGCTT_L001 ad30_TGACCA_L002 ad32_ACTTGA_L001 ad33_GATCAG_L001 ad34_GGCTAC_L003 ad35_CTTGTA_L003 ad3_CGATGT_L002 ad4_ATCACG_L002 ad6_GCCAAT_L004 ad7_ACTTGA_L004 ad9_GATCAG_L003 cr4_TAGCTT_L002 cr5_GGCTAC_L002 cr6_CTTGTA_L002 cr7_GGCTAC_L004 cr8_CTTGTA_L004 f1312_GCCAAT_L001 f1513_CAGATC_L001 f1612_ACAGTG_L001 f1819_CAGATC_L003 f1822_GCCAAT_L003 f2322_ACAGTG_L003 f2524_TGACCA_L004 f2627_GATCAG_L002 f26_CAGATC_L004 f2933_CTTGTA_L001 f3031_GCCAAT_L002 f3332_GGCTAC_L001 f3435_ATCACG_L004 f43_TTAGGC_L002 f710_TAGCTT_L004 f911_TAGCTT_L003)

for i in "${list[@]}"; do
rm ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2.clean.biallelic.noindels_filter_phased_${i}.recode.vcf*
rm ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2.clean.biallelic.noindels_filter_phased_${i}.nohomoRef-nohomoAlt.recode.vcf.gz*
rm ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2.clean.biallelic.noindels_filter_phased_${i}.homoRef.recode.vcf.gz*
rm ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2.clean.biallelic.noindels_filter_phased_${i}.homoAlt.recode.vcf.gz*
rm ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2_${i}.clean.recode.vcf.gz*
done

echo "# finished re-correcting calling"


##-4-## Database for BEAGLE v4.0
#no missing genotypes
#only phased
${toVCFTOOLS}/vcftools --vcf ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2.clean.biallelic.noindels_filter_phased.vcf --keep ${PROOT}/NamesSampleTag_parents_Oad18ad31ad2_Oroulei.txt --phased --stdout --keep-INFO-all --recode > ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2.clean.biallelic.noindels_filter_phased_parents_Oroulei_PHASED.vcf

#remove parents involved in the poorly sequenced offspring / parents (f3031, f1819, f26, f1612)
${toVCFTOOLS}/vcftools --vcf ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2.clean.biallelic.noindels_filter_phased_parents_Oroulei_PHASED.vcf --remove-indv ad12_CGATGT_L001 --remove-indv ad16_ATCACG_L001 --remove-indv ad30_TGACCA_L002 --remove-indv ad19_TGACCA_L003 --remove-indv ad6_GCCAAT_L004 --stdout --keep-INFO-all --recode > ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2.clean.biallelic.noindels_filter_phased_parents_Oroulei_Oad6ad30ad19ad16ad12_PHASED.vcf

#change sample name in the reference panel (***no overlap between reference and non-reference samples***)
cat ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2.clean.biallelic.noindels_filter_phased_parents_Oroulei_Oad6ad30ad19ad16ad12_PHASED.vcf | sed 's/ad/alias.ad/g' > ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2.clean.biallelic.noindels_filter_phased_parents_Oroulei_Oad6ad30ad19ad16ad12_PHASED_alias.vcf


##-5-## Phase by Transmission with BEAGLE v4.0
#https://faculty.washington.edu/browning/beagle/b4_0.html
## It performs genotype calling, haplotype estimation, imputation of ungenotyped markers, homozygosity-by-descent (HBD) and identity-by-descent (IBD) segment detection.
## Parent-offspring relationships can be specified and modelled by use of the ped parameter.
## A reference panel can be specified with the ref parameter. All genotypes in the reference panel must be non-missing and phased. If your reference data has unphased or missing genotypes, you can create a phased reference panel by running Beagle on the unphased reference data (use the gt argument). Use of a population-matched reference panel can increase analysis accuracy. Corresponding variants in the reference and target VCF files must have identical CHROM, POS, REF, and ALT fields. When a reference panel is used, it determines the variants included in the analysis. Variants absent from the reference panel are excluded. Variants in the reference panel that are absent in your data will be imputed. Use the impute=false argument if you do not wish to impute variants that are absent in your data

## Data:
#  --nthreads=[1]	specifies the number of threads of execution to use during haplotype sampling.
#  --gtgl=[file]	specifies a VCF file containing a GT, GL or PL (genotype likelihood) format field for each marker. 
#			The GT field is used if the GT field is present and the genotype is non-missing; otherwise, the GL or PL field is used.
#			If both GL and PL format fields are present for a sample, the GL format will be used.
#  --ref=[file]		specifies a reference VCF file containing additional samples and phased genotypes for each marker.
#  --ped=[file]		specifies a Linkage-format pedigree file for specifying family relationships. The pedigree file has one line per individual.
#			The first 4 white-space delimited fields of each line are 1) pedigree ID, 2) individual ID, 3) father’s ID, and 4) mother’s ID. 
#			A “0” is used in column 3 or 4 if the father or mother is unknown. The individual IDs are required to be unique.
#			Beagle uses the data in columns 2-4 to identify parent-offspring duos and trios in the input data. 
#			Any or all columns of the pedigree file after column 4 may be omitted.
#  --out=[prefix] 	specifies the output filename prefix. The prefix may be an absolute or relative filename, but it cannot be a directory name.
#  --impute=[true] 	specifies whether variants that are present in the ref panel but absent in your data will be imputed.
#			This option has no effect if the ref parameter is not used.
#  --excludesamples=[file]	specifies a file containing non-reference samples (one sample per line) to be excluded from the analysis and output files.
#  --excludemarkers=[file] 	specifies a file containing markers (one marker per line) to be excluded from the analysis and the output files.
#				An excluded marker identifier can either be an identifier from the VCF record’s ID field or genomic coordinates
#				in the format: CHROM:POS.
#  --chrom=[chrom:start-end] 	specifies a chromosome or chromosome interval using a chromosome identifier in the VCF file and the starting and ending positions
#				of the interval. The entire chromosome, the beginning of the chromosome, and the end of a chromosome can be specified by
#				chrom=[chrom], chrom=[chrom:-end], and chrom=[chrom:start-] respectively.
#  --maxlr=[5000] 		specifies the maximum likelihood ratio at a genotype. If M is the maximum of the likelihoods of each possible genotype, 
#				any likelihood that is less than (M /maxlr) is set to 0.0 to improve computational efficiency.
#				If enforcement of the maximum likelihood ratio would causes Mendelian inconsistency in a parent-offspring duo or trio,
#				the maximum likelihood is not enforced for that marker in the duo or trio.
## Algorithm:
#  --window=[50000] 		specifies the number of markers to include in each sliding window.The window parameter must be at least twice as large as
#				the overlap parameter. The window parameter controls the amount of memory used in the analysis.
#  --overlap=[3000]		specifies the number of markers of overlap between sliding windows
#				The overlap parameter must be less than half of the size of the window parameter.
#  --usephase=[false]		specifies whether to use phase information in GT format fields for individuals in the input file specified with the gt or gtgl
#				If usephase=false, the allele order at heterozygous genotypes will be randomized at the start of the analysis
#				Input phase is used only for individuals who are not part of a genotyped parent-offspring duo or trio (see the ped parameter).
#  --singlescale=[0.8] 		specifies the model scale parameter when sampling haplotypes for unrelated individuals.
#				Increasing the singlescale parameter trades reduced single phasing accuracy for reduced run-time.
#  --duoscale=[1.0] 		specifies the model scale parameter when sampling haplotypes for parent-offspring duos.
#				Increasing the duoscale parameter trades reduced duo phasing accuracy for reduced run-time.
#  --trioscale=[1.0] 		specifies the model scale parameter when sampling haplotypes for parent-offspring trios.
#				Increasing the trioscale parameter trades reduced trio phasing accuracy for reduced run-time.
#				Note regarding singlescale, duoscale, and trioscale parameters. The model scale parameters control the model complexity and are
#				normally left at their default values to achieve highest accuracy. However, if the sample size is extremely large or if genotype
#				likelihoods are used, it may be necessary to increase one or more scale parameters to obtain reasonable computation times.
#				For example if the output log file shows that computation time is excessively long when sampling haplotypes for trios, the trioscale
#				parameter can be increased to reduce this computation time. Increasing a scale factor from 1 to r will typically decrease computation
#				time by a factor of approximately r^2 when sampling haplotypes. Computation time scales approximately linearly in the # of markers.
#  --burnin-its=[5]		specifies the number of initial burn-in iterations.
#  --phase-its=[5]		specifies the number of iterations for estimating genotype phase. Increasing it (e.g. to 10) will increase genotype phase accuracy.

## Outputs:
#  The log file gives a summary of the analysis that includes the Beagle version, the command line arguments, and the running time.
#  The warnings file is created if there are any warnings generated during the analysis; 
#  e.g. Mendelian inconsistent genotypes in parent-offspring duos and trios are reported.
#  The output VCF file contains info for all non-reference samples in the analysis. Estimated haplotypes are reported in the GT format field as phased genotypes.
#  An HBD & IBD files are produced when the ibd=true option is specified. Each line of an HBD/IBD output file has 8 fields and represents a detected HBD/IBD segment.

java -Xmx30g -jar ${toBEAGLE}/beagle.r1399.jar \
	nthreads=${nthr} \
	gt=${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2.clean.biallelic.noindels_filter_phased.vcf \
	ref=${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2.clean.biallelic.noindels_filter_phased_parents_Oroulei_Oad6ad30ad19ad16ad12_PHASED_alias.vcf \
	out=${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2.clean.biallelic.noindels_filter_phased_phasedBeagle \
	ped=${PROOT}/NamesTrio_Oad18ad31ad2.ped \
	burnin-its=5 \
	phase-its=10 \
	usephase=false \
	impute=false \
	ibd=false \

gunzip ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2.clean.biallelic.noindels_filter_phased_phasedBeagle.vcf.gz


echo "# finished Phase By Transmission with BEAGLE"
