#! /bin/bash
# indel_realignment_CF
# last edit: 2021-06
# authors: Christelle Fraïsse

#-# usage: 
#	while read line; do
#	qsub indel_realignment_CF.sh ${line}
#	done </share/nas-isem_e/genomique_integrative/Cione_WGS/NamesSample.txt
#-# prog required: GATK v3.4-0-g7e26428
#-# files required: NamesSample.txt [a vector of individual sample names]
#-# description: Indel realignment.


## define global variables
toGATK=/share/nas-isem_e/genomique_integrative/Cione_WGS
refgen=/share/nas-isem_e/genomique_integrative/Cione_WGS/RefCiona/GCA_009617815.1_Ciona_intestinalis_HT_Hoya_T-line_assembly_2019_genomic.fna

## your GATK sample
f=$1
infolder=/share/nas-isem_e/genomique_integrative/Cione_WGS/assembly_2019/ciona_bwa-mapping_${f}


##-1-## Pre-­processing  step  to  find  intervals  that  may  need  realignment
## RealignerTargetCreator finds small suspicious intervals which are likely in need of realignment
java -Xmx4g -jar ${toGATK}/GenomeAnalysisTK.jar \
	-R ${refgen} \
	-T RealignerTargetCreator \
	-I ${infolder}/${f}_bwa_mem_mdup.bam \
	-o ${infolder}/${f}_bwa_mem_mdup.intervals \


##-2-## Running the realigner over those intervals using the IndelRealigner tool
## Performs local realignment of reads to correct misalignments due to the presence of indels
java -Xmx4g -jar ${toGATK}/GenomeAnalysisTK.jar \
	-R ${refgen} \
	-T IndelRealigner \
	-I ${infolder}/${f}_bwa_mem_mdup.bam \
	-targetIntervals ${infolder}/${f}_bwa_mem_mdup.intervals \
	-o ${infolder}/${f}_bwa_mem_mdup_IR.bam \

##### Cleanup
rm -f ${infolder}/${f}_bwa_mem_mdup.bam
rm -f ${infolder}/${f}_bwa_mem_mdup.bai


echo "# finished Indel Realignment for sample ${f} with GATK"
