#! /bin/bash
# snpindel_callingGVCF_raw_CF
# last edit: 2021-06
# authors: Christelle Fraïsse

#-# usage: 
#	while read line; do
#	qsub snpindel_callingGVCF_raw_CF.sh ${line}
#	done </share/nas-isem_e/genomique_integrative/Cione_WGS/NamesSample.txt
#-# prog required: GATK v3.4-0-g7e26428
#-# files required: NamesSample.txt [a vector of individual sample names]
#-# description: Calling snps and indels, including invariant sites.


## define global variables
toGATK=/share/nas-isem_e/genomique_integrative/Cione_WGS
refgen=/share/nas-isem_e/genomique_integrative/Cione_WGS/RefCiona/GCA_009617815.1_Ciona_intestinalis_HT_Hoya_T-line_assembly_2019_genomic.fna

## your GATK sample
f=$1
infolder=/share/nas-isem_e/genomique_integrative/Cione_WGS/assembly_2019/ciona_bwa-mapping_${f}

## number of threads to use
nthr=10


##### HaplotypeCaller on single samples in gVCF format (non-variant block record)
## Call SNPs and indels simultaneously via local re-assembly of haplotypes in an active region
## Read Backed Phasing is automatically computed
## PED information is not use during the variant calling process
#  --genotyping_mode			Specifies how to determine the alternate alleles to use for genotyping [DISCOVERY; GENOTYPE_GIVEN_ALLELES]
#  --group				One or more classes/groups of annotations to apply to variant calls. 
#					See the VariantAnnotator -list argument to view available groups ('annotates variant calls with context information')
#					Pedigree-related annotations : the pedigree information is not used during the variant calling process.
#					For these tools, the PED files must contain only the first 6 columns from the PLINK format PED file, and no alleles.
#  --heterozygosity		0.001	The expected heterozygosity value used to compute prior probability that a locus is non-reference. 
#					That is, a hets value of 0.01 implies that two randomly chosen chromosomes from the population of organisms would differ
#					from each other (one being A and the other B) at a rate of 1 in 100 bp.
#  --indel_heterozygosity 	1.25E-4	The expected heterozygosity for indel calling
#  --maxReadsInRegionPerSample 	1000	Maximum reads in an active region
#  --min_base_quality_score 	10	Minimum base quality required to consider a base for calling
#  --minReadsPerAlignmentStart 	5	Minimum number of reads sharing the same alignment start for each genomic location in an active region
#  --output_mode			Specifies which type of calls we should output [EMIT_VARIANTS_ONLY; EMIT_ALL_CONFIDENT_SITES; EMIT_ALL_SITES]
#  -stand_call_conf 		30	The minimum phred-scaled confidence threshold at which variants should be called
#  -stand_emit_conf		30	The minimum phred-scaled confidence threshold at which variants should be emitted (and filtered with LowQual)
#  --bamOutput 			NA	File to which assembled haplotypes should be written
#  --indelSizeToEliminateInRefModel 10  This parameter determines the maximum size of an indel considered as potentially segregating in the reference model
#  --max_alternate_alleles 	6	If there are more than this number of alternate alleles presented to the genotyper, then only this many alleles will be used
#  --maxNumHaplotypesInPopulation 128	Maximum number of haplotypes to consider for your population. You can increase it when calling high heterozygosity organisms
#  --doNotRunPhysicalPhasing 	NA	Don't try to add physical (read-based) phasing information
#  --dontUseSoftClippedBases 	NA	Do not analyze soft clipped bases in the reads
#  --mergeVariantsViaLD		NA	Merge variants together into block substitutions if they are in strong local LD
#  --emitRefConfidence 		NA	Mode for emitting reference confidence scores
#					GVCF mode: record for all sites whether there is a variant call there or not
#  -- variant_index_type _parameter	Related to file compression

## Settings
# Mode: BY_SAMPLE
# To coverage: 250
# Minimum region size: 50 bp
# Maximum region size: 300 bp
# Extension increments: 100 bp

#FORMAT
#GT Genotype
#AD Allelic depths for the ref and alt alleles in the order listed
#DP Approximate read depth, some reads may have been filtered
#GQ Genotype quality
#PGT Physical phasing haplotype information -how alternate alleles are phased in relation to one another
#PID Physical phasing haplotype information -where each unique ID within a given sample connects records within a phasing group
#PL Phred-lukelihoods for genotypes -VCF specification

java -Xmx4g -jar ${toGATK}/GenomeAnalysisTK.jar \
	-nct ${nthr} \
	-T HaplotypeCaller \
	-R ${refgen} \
	-I ${infolder}/${f}_bwa_mem_mdup_IR.bam \
	-o ${infolder}/${f}_bwa_mem_mdup_IR_raw.g.vcf \
	--dontUseSoftClippedBases \
	--heterozygosity 0.01 \
	--min_base_quality_score 30 \
	-stand_call_conf 30.0 \
	--genotyping_mode DISCOVERY \
	--emitRefConfidence GVCF \
	--variant_index_type LINEAR \
	--variant_index_parameter 128000 \

	
echo "# finished Raw Variant Calling GVCF for sample ${f} with GATK"
