#! /bin/bash
# joint_genotyping_raw_CF
# last edit: 2021-06
# authors: Christelle Fraïsse

#-# usage: qsub joint_genotyping_raw_CF.sh
#-# prog required: GATK v3.4-0-g7e26428
#-# files required: NamesSample.txt [a vector of individual sample names]
#-# description: Raw joint genotyping.


## define global variables
toGATK=/share/nas-isem_e/genomique_integrative/Cione_WGS
PROOT="/share/nas-isem_e/genomique_integrative/Cione_WGS"
PROOTbis="/share/nas-isem_e/genomique_integrative/Cione_WGS/assembly_2019"
refgen=/share/nas-isem_e/genomique_integrative/Cione_WGS/RefCiona/GCA_009617815.1_Ciona_intestinalis_HT_Hoya_T-line_assembly_2019_genomic.fna

## your GATK sample
infolder=/share/nas-isem_e/genomique_integrative/Cione_WGS/assembly_2019/ciona_bwa-mapping

## create new folder
outfolder=/share/nas-isem_e/genomique_integrative/Cione_WGS/assembly_2019/ciona_bwa-mapping_jointsamples_raw
mkdir -p ${outfolder}

## number of threads to use
nthr=30


##### GenotypeGVCFs: joint genotyping of trios
## Genotypes any number of gVCF files that were produced by the Haplotype Caller into a single joint VCF file.
#  --heterozygosity	0.001		The expected heterozygosity value used to compute prior probability that a locus is non-reference
#  --indel_heterozygosity 1.25E-4	The expected heterozygosity for indel calling
#  -stand_call_conf 	30		The minimum phred-scaled confidence threshold at which variants should be called
#  -stand_emit_conf	30		The minimum phred-scaled confidence threshold at which variants should be emitted (and filtered with LowQual)
#  --includeNonVariantSites	NA	Include loci found to be non-variant after genotyping
#  --input_prior 	NA		Input prior for calls. 
#					By default, the prior specified with the argument --heterozygosity is used for variant discovery at a particular locus, 
#					using an infinite sites model, see e.g. Waterson (1975) or Tajima (1996).
#  --max_alternate_alleles 6		If there are more than this number of alternate alleles presented to the genotyper, then only this many alleles will be used

# store the full command line to include it in the next part
echo "java -Xmx30g -jar ${toGATK}/GenomeAnalysisTK.jar
	-nt ${nthr}
	-T GenotypeGVCFs
	-R ${refgen}
	--heterozygosity 0.01
	-stand_call_conf 30
	-o ${outfolder}/joint_bwa_mem_mdup_IR_raw.vcf" > ${PROOTbis}/list_gVCFRaw.txt

while read line; do echo "-V ${infolder}_${line}/${line}_bwa_mem_mdup_IR_raw.g.vcf" >> ${PROOTbis}/list_gVCFRaw.txt; done <${PROOT}/NamesSample.txt

# display the full command with expanded variables
echo "# the command will be:"
cmd=`cat ${PROOTbis}/list_gVCFRaw.txt`
echo ${cmd}
 
# execute the command
eval ${cmd} 2>${outfolder}/jointsamples_bwa_mem.err


echo "# finished Raw Joint Genotyping with GATK"
