#! /bin/bash
# phase_by_transmission_correctCalling_CF@2020
# last edit: 2021-06
# authors: Christelle Fraïsse

#-# usage: qsub phase_by_transmission_correctCalling_CF@2020.sh
#-# prog required: vcftools v0.1.13 ; htslib v1.9 ; bcftools v1.9
#-# files required: None 
#-# description: Phase by transmission - correct calling.


## define global variables
toVCFTOOLS=/home/fchristelle/bin/vcftools_0.1.13/bin
toHTSLIB=/home/fchristelle/bin/htslib-1.9
toBCFTOOLS=/home/fchristelle/bin/bcftools-1.9
refgen=/share/nas-isem_e/genomique_integrative/Cione_WGS/RefCiona/GCA_009617815.1_Ciona_intestinalis_HT_Hoya_T-line_assembly_2019_genomic.fna

## your joint sample
infolder=/share/nas-isem_e/genomique_integrative/Cione_WGS/assembly_2019/ciona_bwa-mapping_jointsamples_raw

## number of threads to use
nthr=30


##-1-## Clean-up data
## Remove poorly-sequenced parents: ad18, ad31; ad2
${toVCFTOOLS}/vcftools --vcf ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo.vcf --remove-indv ad18_TTAGGC_L003 --remove-indv ad31_ACAGTG_L002 --remove-indv ad2_ACAGTG_L004 --recode --recode-INFO-all --out ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2
mv ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2.recode.vcf ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2.vcf


## Extract the allele depth "AD1/(AD0+AD1)" distribution for each individual and each genotype class
list=(ad10_GATCAG_L004 ad11_ACTTGA_L003 ad12_CGATGT_L001 ad13_TTAGGC_L001 ad15_TGACCA_L001 ad16_ATCACG_L001 ad19_TGACCA_L003 ad22_CGATGT_L003 ad23_ATCACG_L003 ad24_TTAGGC_L004 ad25_CGATGT_L004 ad26_CAGATC_L002 ad27_ACTTGA_L002 ad29_TAGCTT_L001 ad30_TGACCA_L002 ad32_ACTTGA_L001 ad33_GATCAG_L001 ad34_GGCTAC_L003 ad35_CTTGTA_L003 ad3_CGATGT_L002 ad4_ATCACG_L002 ad6_GCCAAT_L004 ad7_ACTTGA_L004 ad9_GATCAG_L003 cr4_TAGCTT_L002 cr5_GGCTAC_L002 cr6_CTTGTA_L002 cr7_GGCTAC_L004 cr8_CTTGTA_L004 f1312_GCCAAT_L001 f1513_CAGATC_L001 f1612_ACAGTG_L001 f1819_CAGATC_L003 f1822_GCCAAT_L003 f2322_ACAGTG_L003 f2524_TGACCA_L004 f2627_GATCAG_L002 f26_CAGATC_L004 f2933_CTTGTA_L001 f3031_GCCAAT_L002 f3332_GGCTAC_L001 f3435_ATCACG_L004 f43_TTAGGC_L002 f710_TAGCTT_L004 f911_TAGCTT_L003)

for i in "${list[@]}"; do
echo ${i}
${toVCFTOOLS}/vcftools --vcf ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2.vcf --indv ${i} --recode --recode-INFO-all --out ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2_${i}
cat ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2_${i}.recode.vcf | grep -v "#" | cut -f1,2,10 | tr ":" "\t"  | sed -e 's/,/\t/g' | cut -f1,2,3,4,5 > ${infolder}/tmp_${i}
done

############################################################################################################## R script
#R --vanilla < ${infolder}/filterGeno.R --args ${infolder}/tmp_${i}
cmd_args <- commandArgs(trailingOnly = TRUE)
filterGeno<-function(y){
	#$V1=chromosome; $V2=SNP position; $V3=genotype; $V4=allele depth reference allele; $V5=allele depth alternate allele
	#Read individual VCF
	x=read.table(y,h=F)
	myind=strsplit(y,"tmp_")[[1]][2]

	#Tag sites with inadequate absolute allele depth: AD total < 10 reads and > Q99% at all sites
	rmAD=which( ((x$V4+x$V5) < 10) | ((x$V4+x$V5) > quantile((x$V4+x$V5),0.99,na.rm=T)) )

	#Extract genotype classes and plot the corresponding distributions on adequate sites
	xRM=x[-rmAD,]
	HET=which( (xRM$V3=="1|0") | (xRM$V3=="0|1") | (xRM$V3=="1/0") | (xRM$V3=="0/1") )
	HOR=which( (xRM$V3=="0|0") | (xRM$V3=="0/0") )
	HOA=which( (xRM$V3=="1|1") | (xRM$V3=="1/1") )
	xHET=xRM[HET,]
	xHOR=xRM[HOR,]
	xHOA=xRM[HOA,]

	pdf(file=paste0("alleleDepth_",myind,"_Geno.pdf"),w=8,h=8)
	par(mar=c(2,5,4,1))
	layout(matrix(c(1,1,2,3), 2, 2, byrow=T))
	AD0=xHET$V4
	AD1=xHET$V5
	AD1f=AD1/(AD0+AD1)
	hist(AD1f,col=c("#00000080"),ylab="AD1/(AD0+AD1) - 0/1 sites",xlab="",cex=1.25,cex.axis=1.25,cex.lab=1.25,main="")
	mtext(3,cex=1.2,text=paste0(myind),padj=-3)
	mtext(3,cex=1,text=paste0("AD0: avg=",round(mean(AD0),2)," ; AD1: avg=",round(mean(AD1),2)," ; n=",nrow(xHET)),padj=-1)
	mtext(3,cex=1,text=paste0("Q1%=",round(quantile(AD1f,probs=0.01,na.rm=T),2),"; Q5%=",round(quantile(AD1f,probs=0.05,na.rm=T),2),"; Q25%=",round(quantile(AD1f,probs=0.25,na.rm=T),2),"; Q50%=",round(quantile(AD1f,probs=0.50,na.rm=T),2),"; Q75%=",round(quantile(AD1f,probs=0.75,na.rm=T),2),"; Q95%=",round(quantile(AD1f,probs=0.95,na.rm=T),2),"; Q99%=",round(quantile(AD1f,probs=0.99,na.rm=T),2)),padj=1)
	AD0=xHOR$V4
	AD1=xHOR$V5
	AD1f=AD1/(AD0+AD1)
	hist(AD1f,col=c("#FFFF66"),ylab="AD1/(AD0+AD1) - 0/0 sites",xlab="",cex=1.25,cex.axis=1.25,cex.lab=1.25,main="")
	mtext(3,cex=1,text=paste0("AD0: avg=",round(mean(AD0),2)," ; AD1: avg=",round(mean(AD1),2)," ; n=",nrow(xHOR)),padj=-3)
	mtext(3,cex=1,text=paste0("Q50%=",round(quantile(AD1f,probs=0.50,na.rm=T),2),"; Q90%=",round(quantile(AD1f,probs=0.90,na.rm=T),2),"; Q95%=",round(quantile(AD1f,probs=0.95,na.rm=T),2),"; Q99%=",round(quantile(AD1f,probs=0.99,na.rm=T),2)),padj=-1)
	mtext(3,cex=1,text=paste0("Q99.5%=",round(quantile(AD1f,probs=0.995,na.rm=T),2),"; Q99.9%=",round(quantile(AD1f,probs=0.999,na.rm=T),2)),padj=1)
	AD0=xHOA$V4
	AD1=xHOA$V5
	AD1f=AD1/(AD0+AD1)
	hist(AD1f,col=c("#FF3333"),ylab="AD1/(AD0+AD1) - 1/1 sites",xlab="",cex=1.25,cex.axis=1.25,cex.lab=1.25,main="")
	mtext(3,cex=1,text=paste0("AD0: avg=",round(mean(AD0),2)," ; AD1: avg=",round(mean(AD1),2)," ; n=",nrow(xHOA)),padj=-3)
	mtext(3,cex=1,text=paste0("Q50%=",round(quantile(AD1f,probs=0.50,na.rm=T),2),"; Q10%=",round(quantile(AD1f,probs=0.10,na.rm=T),2),"; Q5%=",round(quantile(AD1f,probs=0.05,na.rm=T),2),"; Q1%=",round(quantile(AD1f,probs=0.01,na.rm=T),2)),padj=-1)
	mtext(3,cex=1,text=paste0("Q0.5%=",round(quantile(AD1f,probs=0.005,na.rm=T),2),"; Q0.1%=",round(quantile(AD1f,probs=0.001,na.rm=T),2)),padj=1)
	graphics.off()

	#Extract genotype classes and apply calling thresholds on raw heterozygous sites
	HETraw=which( (x$V3=="1/0") | (x$V3=="0/1") )
	xHETraw=x[HETraw,]
	AD1fHETraw=xHETraw$V5/(xHETraw$V4+xHETraw$V5)
	AD1fHET=xHET$V5/(xHET$V4+xHET$V5)
	AD1fHOR=xHOR$V5/(xHOR$V4+xHOR$V5)
	AD1fHOA=xHOA$V5/(xHOA$V4+xHOA$V5)

	#Tag heterozygous sites 
		#to call as "0/0": het sites with AD1f <= Q99.9% of "0/0" sites (AD1f~0.1) 
		adHOR=which( (AD1fHETraw <= round(quantile(AD1fHOR,probs=0.999,na.rm=T),2)) )
		#to call as "1/1": het sites with AD1f >= Q0.1% of "1/1" sites (AD1f~0.9) 
		adHOA=which( (AD1fHETraw >= round(quantile(AD1fHOA,probs=0.001,na.rm=T),2)) )
		#to call as "./.": het sites that are outside the range "2/3 < AD1f < 1/3" of "0/1" sites (which corresponds to "0.5 > AD0/AD1 > 2")
		rmHET=which( (AD1fHETraw < 1/3) | (AD1fHETraw > 2/3) )
		#to call as "./.": het sites that are outside the range "Q25% < AD1f < Q75%" of "0/1" sites
		#rmHET=which( (AD1fHETraw < round(quantile(AD1fHET,probs=0.25,na.rm=T),2)) | (AD1fHETraw > round(quantile(AD1fHET,probs=0.75,na.rm=T),2)) )

		#de-tag from rmHET those sites that are in adHOR or adHOA: elements in vec1 that are not in vec2 = vec1[is.na(match(vec1,vec2))]
		rmHET <- rmHET[is.na(match(rmHET,adHOR))]
		rmHET <- rmHET[is.na(match(rmHET,adHOA))]
		#remove duplicates between rmAD and rmHET
		rmALL=c(rmAD,HETraw[rmHET]) ; rmALL=rmALL[-which(duplicated(rmALL)==T)] ; rmALL=sort(rmALL)
		#de-tag from adHOR or adHOA those sites that are in rmALL
		HETrawadHOR <- HETraw[adHOR][is.na(match(HETraw[adHOR],rmALL))] ; HETrawadHOR=sort(HETrawadHOR)
		HETrawadHOA <- HETraw[adHOA][is.na(match(HETraw[adHOA],rmALL))] ; HETrawadHOA=sort(HETrawadHOA)
	
	#Write down which "Chromosome Position" to tag 
		#as homozygous reference genotypes "0/0"
		write.table(x[HETrawadHOR,c("V1","V2")],file=paste0(y,"_homoRef"),append=F,quote=F,col.names=F,row.names=F,sep="\t")
		#as homozygous alternate genotypes "1/1"
		write.table(x[HETrawadHOA,c("V1","V2")],file=paste0(y,"_homoAlt"),append=F,quote=F,col.names=F,row.names=F,sep="\t")
		#as missing genotypes "./." due to absolute AD and relative AD for het sites
		write.table(x[rmALL,c("V1","V2")],file=paste0(y,"_remove"),append=F,quote=F,col.names=F,row.names=F,sep="\t")
}
filterGeno(cmd_args)
############################################################################################################## R script


## Modify individual VCFs to replace the identified positions by specific genotypes
list=(ad10_GATCAG_L004 ad11_ACTTGA_L003 ad12_CGATGT_L001 ad13_TTAGGC_L001 ad15_TGACCA_L001 ad16_ATCACG_L001 ad19_TGACCA_L003 ad22_CGATGT_L003 ad23_ATCACG_L003 ad24_TTAGGC_L004 ad25_CGATGT_L004 ad26_CAGATC_L002 ad27_ACTTGA_L002 ad29_TAGCTT_L001 ad30_TGACCA_L002 ad32_ACTTGA_L001 ad33_GATCAG_L001 ad34_GGCTAC_L003 ad35_CTTGTA_L003 ad3_CGATGT_L002 ad4_ATCACG_L002 ad6_GCCAAT_L004 ad7_ACTTGA_L004 ad9_GATCAG_L003 cr4_TAGCTT_L002 cr5_GGCTAC_L002 cr6_CTTGTA_L002 cr7_GGCTAC_L004 cr8_CTTGTA_L004 f1312_GCCAAT_L001 f1513_CAGATC_L001 f1612_ACAGTG_L001 f1819_CAGATC_L003 f1822_GCCAAT_L003 f2322_ACAGTG_L003 f2524_TGACCA_L004 f2627_GATCAG_L002 f26_CAGATC_L004 f2933_CTTGTA_L001 f3031_GCCAAT_L002 f3332_GGCTAC_L001 f3435_ATCACG_L004 f43_TTAGGC_L002 f710_TAGCTT_L004 f911_TAGCTT_L003)

#missing genotypes
for i in "${list[@]}"; do
echo ${i}
${toVCFTOOLS}/vcftools --vcf ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2_${i}.recode.vcf --exclude-positions ${infolder}/tmp_${i}_remove --recode --recode-INFO-all --out ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2_${i}.nomissing
${toVCFTOOLS}/vcftools --vcf ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2_${i}.recode.vcf --positions ${infolder}/tmp_${i}_remove --recode --recode-INFO-all --out ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2_${i}.tmp
${toBCFTOOLS}/bcftools +setGT ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2_${i}.tmp.recode.vcf -- -t 'a' -n './.' > ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2_${i}.missing.recode.vcf
rm ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2_${i}.tmp.recode.vcf
done

#homoRef genotypes
for i in "${list[@]}"; do
echo ${i}
${toVCFTOOLS}/vcftools --vcf ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2_${i}.nomissing.recode.vcf --exclude-positions ${infolder}/tmp_${i}_homoRef --recode --recode-INFO-all --out ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2_${i}.nomissing-nohomoRef
${toVCFTOOLS}/vcftools --vcf ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2_${i}.recode.vcf --positions ${infolder}/tmp_${i}_homoRef --recode --recode-INFO-all --out ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2_${i}.tmp
${toBCFTOOLS}/bcftools +setGT ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2_${i}.tmp.recode.vcf -- -t 'a' -n '0/0' > ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2_${i}.homoRef.recode.vcf
rm ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2_${i}.tmp.recode.vcf
rm ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2_${i}.nomissing.recode.vcf
done

#homoAlt genotypes
for i in "${list[@]}"; do
echo ${i}
${toVCFTOOLS}/vcftools --vcf ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2_${i}.nomissing-nohomoRef.recode.vcf --exclude-positions ${infolder}/tmp_${i}_homoAlt --recode --recode-INFO-all --out ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2_${i}.nomissing-nohomoRef-nohomoAlt
${toVCFTOOLS}/vcftools --vcf ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2_${i}.recode.vcf --positions ${infolder}/tmp_${i}_homoAlt --recode --recode-INFO-all --out ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2_${i}.tmp
${toBCFTOOLS}/bcftools +setGT ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2_${i}.tmp.recode.vcf -- -t 'a' -n '0/0' > ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2_${i}.homoAlt.recode.vcf
sed -i 's/0\/0:/1\/1:/g' ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2_${i}.homoAlt.recode.vcf
rm ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2_${i}.tmp.recode.vcf
rm ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2_${i}.nomissing-nohomoRef.recode.vcf
done


## Concatenating all VCFs for each individual
list=(ad10_GATCAG_L004 ad11_ACTTGA_L003 ad12_CGATGT_L001 ad13_TTAGGC_L001 ad15_TGACCA_L001 ad16_ATCACG_L001 ad19_TGACCA_L003 ad22_CGATGT_L003 ad23_ATCACG_L003 ad24_TTAGGC_L004 ad25_CGATGT_L004 ad26_CAGATC_L002 ad27_ACTTGA_L002 ad29_TAGCTT_L001 ad30_TGACCA_L002 ad32_ACTTGA_L001 ad33_GATCAG_L001 ad34_GGCTAC_L003 ad35_CTTGTA_L003 ad3_CGATGT_L002 ad4_ATCACG_L002 ad6_GCCAAT_L004 ad7_ACTTGA_L004 ad9_GATCAG_L003 cr4_TAGCTT_L002 cr5_GGCTAC_L002 cr6_CTTGTA_L002 cr7_GGCTAC_L004 cr8_CTTGTA_L004 f1312_GCCAAT_L001 f1513_CAGATC_L001 f1612_ACAGTG_L001 f1819_CAGATC_L003 f1822_GCCAAT_L003 f2322_ACAGTG_L003 f2524_TGACCA_L004 f2627_GATCAG_L002 f26_CAGATC_L004 f2933_CTTGTA_L001 f3031_GCCAAT_L002 f3332_GGCTAC_L001 f3435_ATCACG_L004 f43_TTAGGC_L002 f710_TAGCTT_L004 f911_TAGCTT_L003)

for i in "${list[@]}"; do
echo ${i}

${toHTSLIB}/bgzip ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2_${i}.nomissing-nohomoRef-nohomoAlt.recode.vcf
${toHTSLIB}/tabix -p vcf ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2_${i}.nomissing-nohomoRef-nohomoAlt.recode.vcf.gz

${toHTSLIB}/bgzip ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2_${i}.missing.recode.vcf
${toHTSLIB}/tabix -p vcf ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2_${i}.missing.recode.vcf.gz

${toHTSLIB}/bgzip ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2_${i}.homoRef.recode.vcf
${toHTSLIB}/tabix -p vcf ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2_${i}.homoRef.recode.vcf.gz

${toHTSLIB}/bgzip ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2_${i}.homoAlt.recode.vcf
${toHTSLIB}/tabix -p vcf ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2_${i}.homoAlt.recode.vcf.gz

${toBCFTOOLS}/bcftools concat -a ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2_${i}.nomissing-nohomoRef-nohomoAlt.recode.vcf.gz ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2_${i}.missing.recode.vcf.gz ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2_${i}.homoRef.recode.vcf.gz ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2_${i}.homoAlt.recode.vcf.gz > ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2_${i}.clean.recode.vcf

cat ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2_${i}.recode.vcf | grep -v "#" | wc -l
cat ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2_${i}.clean.recode.vcf | grep -v "#" | wc -l

${toHTSLIB}/bgzip ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2_${i}.clean.recode.vcf
${toHTSLIB}/tabix -p vcf ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2_${i}.clean.recode.vcf.gz

done


## Merge VCFs across individuals
${toBCFTOOLS}/bcftools merge --threads ${nthr} ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2_ad10_GATCAG_L004.clean.recode.vcf.gz ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2_ad11_ACTTGA_L003.clean.recode.vcf.gz ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2_ad12_CGATGT_L001.clean.recode.vcf.gz ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2_ad13_TTAGGC_L001.clean.recode.vcf.gz ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2_ad15_TGACCA_L001.clean.recode.vcf.gz ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2_ad16_ATCACG_L001.clean.recode.vcf.gz ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2_ad19_TGACCA_L003.clean.recode.vcf.gz ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2_ad22_CGATGT_L003.clean.recode.vcf.gz ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2_ad23_ATCACG_L003.clean.recode.vcf.gz ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2_ad24_TTAGGC_L004.clean.recode.vcf.gz ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2_ad25_CGATGT_L004.clean.recode.vcf.gz ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2_ad26_CAGATC_L002.clean.recode.vcf.gz ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2_ad27_ACTTGA_L002.clean.recode.vcf.gz ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2_ad29_TAGCTT_L001.clean.recode.vcf.gz ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2_ad30_TGACCA_L002.clean.recode.vcf.gz ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2_ad32_ACTTGA_L001.clean.recode.vcf.gz ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2_ad33_GATCAG_L001.clean.recode.vcf.gz ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2_ad34_GGCTAC_L003.clean.recode.vcf.gz ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2_ad35_CTTGTA_L003.clean.recode.vcf.gz ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2_ad3_CGATGT_L002.clean.recode.vcf.gz ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2_ad4_ATCACG_L002.clean.recode.vcf.gz ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2_ad6_GCCAAT_L004.clean.recode.vcf.gz ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2_ad7_ACTTGA_L004.clean.recode.vcf.gz ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2_ad9_GATCAG_L003.clean.recode.vcf.gz ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2_cr4_TAGCTT_L002.clean.recode.vcf.gz ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2_cr5_GGCTAC_L002.clean.recode.vcf.gz ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2_cr6_CTTGTA_L002.clean.recode.vcf.gz ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2_cr7_GGCTAC_L004.clean.recode.vcf.gz ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2_cr8_CTTGTA_L004.clean.recode.vcf.gz ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2_f1312_GCCAAT_L001.clean.recode.vcf.gz ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2_f1513_CAGATC_L001.clean.recode.vcf.gz ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2_f1612_ACAGTG_L001.clean.recode.vcf.gz ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2_f1819_CAGATC_L003.clean.recode.vcf.gz ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2_f1822_GCCAAT_L003.clean.recode.vcf.gz ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2_f2322_ACAGTG_L003.clean.recode.vcf.gz ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2_f2524_TGACCA_L004.clean.recode.vcf.gz ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2_f2627_GATCAG_L002.clean.recode.vcf.gz ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2_f26_CAGATC_L004.clean.recode.vcf.gz ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2_f2933_CTTGTA_L001.clean.recode.vcf.gz ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2_f3031_GCCAAT_L002.clean.recode.vcf.gz ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2_f3332_GGCTAC_L001.clean.recode.vcf.gz ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2_f3435_ATCACG_L004.clean.recode.vcf.gz ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2_f43_TTAGGC_L002.clean.recode.vcf.gz ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2_f710_TAGCTT_L004.clean.recode.vcf.gz ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2_f911_TAGCTT_L003.clean.recode.vcf.gz > ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2.clean.vcf

cat ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo.vcf | grep -v "#" | wc -l
cat ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2.clean.vcf | grep -v "#" | wc -l


## Generate a biallelic VCF without indels
${toVCFTOOLS}/vcftools --vcf ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2.clean.vcf --remove-indels --min-alleles 2 --max-alleles 2 --recode --recode-INFO-all --out ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2.clean.biallelic.noindels

mv ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2.clean.biallelic.noindels.recode.vcf ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2.clean.biallelic.noindels.vcf


## Arrange files
list=(ad10_GATCAG_L004 ad11_ACTTGA_L003 ad12_CGATGT_L001 ad13_TTAGGC_L001 ad15_TGACCA_L001 ad16_ATCACG_L001 ad19_TGACCA_L003 ad22_CGATGT_L003 ad23_ATCACG_L003 ad24_TTAGGC_L004 ad25_CGATGT_L004 ad26_CAGATC_L002 ad27_ACTTGA_L002 ad29_TAGCTT_L001 ad30_TGACCA_L002 ad32_ACTTGA_L001 ad33_GATCAG_L001 ad34_GGCTAC_L003 ad35_CTTGTA_L003 ad3_CGATGT_L002 ad4_ATCACG_L002 ad6_GCCAAT_L004 ad7_ACTTGA_L004 ad9_GATCAG_L003 cr4_TAGCTT_L002 cr5_GGCTAC_L002 cr6_CTTGTA_L002 cr7_GGCTAC_L004 cr8_CTTGTA_L004 f1312_GCCAAT_L001 f1513_CAGATC_L001 f1612_ACAGTG_L001 f1819_CAGATC_L003 f1822_GCCAAT_L003 f2322_ACAGTG_L003 f2524_TGACCA_L004 f2627_GATCAG_L002 f26_CAGATC_L004 f2933_CTTGTA_L001 f3031_GCCAAT_L002 f3332_GGCTAC_L001 f3435_ATCACG_L004 f43_TTAGGC_L002 f710_TAGCTT_L004 f911_TAGCTT_L003)

for i in "${list[@]}"; do
echo ${i}
mv ${infolder}/tmp_${i}_remove ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2_${i}_all2missing.pos
mv ${infolder}/tmp_${i}_homoRef ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2_${i}_het2homoRef.pos
mv ${infolder}/tmp_${i}_homoAlt ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2_${i}_het2homoAlt.pos

rm ${infolder}/tmp_${i}
rm ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2_${i}.recode.vcf*
rm ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2_${i}.nomissing-nohomoRef-nohomoAlt.recode.vcf.gz*
rm ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2_${i}.missing.recode.vcf.gz*
rm ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2_${i}.homoRef.recode.vcf.gz*
rm ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2_${i}.homoAlt.recode.vcf.gz*
rm ${infolder}/joint_bwa_mem_mdup_IR_recal_variants_refine_HQ_denovo_Oad18ad31ad2_${i}.clean.recode.vcf.gz*
done


echo "# finished correcting calling"
